<?php
namespace Inti\Google\Api;

use Inti\Google\Service\Drive\DriveMiddleware;
use Psr\Container\ContainerInterface;
use Zend\Expressive\Application;
use Zend\Expressive\Authentication\AuthenticationMiddleware;
use Zend\Expressive\Authorization\AuthorizationMiddleware;

/**
 * Class ApplicationDelegate
 *
 * @package Inti\Google\Api
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-google
 */
final class ApplicationDelegator
{
    /**
     * @param ContainerInterface $container
     * @param string $serviceName
     * @param callable $callback
     * @return Application
     */
    public function __invoke(ContainerInterface $container, string $serviceName, callable $callback): Application
    {
        /** @var Application $app */
        $app = $callback();

        $app->get('/api/google/folders', array_filter([
            AuthenticationMiddleware::class,
            AuthorizationMiddleware::class,
            DriveMiddleware::class,
            Drive\FoldersHandler::class,
        ], [$container, 'has']), 'api.google.folders');

        $app->get('/api/google/drives', array_filter([
            AuthenticationMiddleware::class,
            AuthorizationMiddleware::class,
            DriveMiddleware::class,
            Drive\DrivesHandler::class,
        ], [$container, 'has']), 'api.google.drives');

        $app->post('/api/google/sheets', array_filter([
            AuthenticationMiddleware::class,
            AuthorizationMiddleware::class,
            DriveMiddleware::class,
            Sheets\CreateHandler::class,
        ], [$container, 'has']), 'api.google.sheets.create');

        $app->get('/api/google/sheets', array_filter([
            AuthenticationMiddleware::class,
            AuthorizationMiddleware::class,
            DriveMiddleware::class,
            Sheets\ListHandler::class,
        ], [$container, 'has']), 'api.google.sheets.list');

        $app->delete('/api/google/sheets/:id', array_filter([
            AuthenticationMiddleware::class,
            AuthorizationMiddleware::class,
            DriveMiddleware::class,
            Sheets\DeleteHandler::class,
        ], [$container, 'has']), 'api.google.sleets.delete');

        return $app;
    }
}
