<?php
namespace Inti\Google\Api\Drive;

use Google_Service_Drive;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Zend\Diactoros\Response\JsonResponse;

/**
 * Class FoldersHandler
 *
 * @package Inti\Google\Api\Handler
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-google
 */
final class FoldersHandler implements RequestHandlerInterface
{
    /**
     * Handles a request and produces a response.
     *
     * May call other collaborating code to generate the response.
     *
     * @param ServerRequestInterface $request
     * @return ResponseInterface
     */
    public function handle(ServerRequestInterface $request): ResponseInterface
    {
        /** @var Google_Service_Drive $drive */
        $drive = $request->getAttribute('google-drive');

        $response = $drive->files->listFiles([
            'q' => "mimeType='application/vnd.google-apps.folder'",
            'fields' => 'files/id, files/name, files/parents',
        ]);

        $folders = [];

        foreach ($response->getFiles() as $file) {
            $folders[] = [
                'id' => $file->id,
                'name' => $file->name,
                'parents' => $file->parents,
            ];
        }

        return new JsonResponse($folders);
    }
}
