<?php
namespace Inti\Google\Api\Sheets;

use Google_Service_Drive;
use Google_Service_Drive_DriveFile;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Zend\Diactoros\Response\JsonResponse;

/**
 * Class CreateHandler
 *
 * @package Inti\Google\Api\Sheets
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-google
 */
final class CreateHandler implements RequestHandlerInterface
{
    /**
     * Handles a request and produces a response.
     *
     * May call other collaborating code to generate the response.
     *
     * @param ServerRequestInterface $request
     * @return ResponseInterface
     */
    public function handle(ServerRequestInterface $request): ResponseInterface
    {
        /** @var Google_Service_Drive $drive */
        $drive = $request->getAttribute('google-drive');
        $params = json_decode($request->getBody()->getContents(), true);

        $spreadsheet = new Google_Service_Drive_DriveFile();
        $spreadsheet->setMimeType('application/vnd.google-apps.spreadsheet');
        $spreadsheet->setName($params['name']);
        $spreadsheet->setParents([$params['folder']]);

        $file = $drive->files->create($spreadsheet);

        return new JsonResponse([
            'id' => $file->id,
            'name' => $file->name,
            'parents' => $file->parents,
        ]);
    }
}
