<?php
namespace Inti\Google;

use Google_Client;
use Google_Service_Drive;
use Google_Service_Sheets;

/**
 * Class ConfigProvider
 *
 * @package Inti\Google
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-google
 */
final class ConfigProvider
{
    /**
     * @return array
     */
    public function __invoke(): array
    {
        return [
            'google' => $this->getDefaultConfig(),
            'dependencies' => $this->getDependencies(),
        ];
    }

    /**
     * @return array
     */
    public function getDefaultConfig(): array
    {
        return [
            'application_name' => '',
            'credentials' => [
                'type' => '',
                'project_id' => '',
                'private_key_id' => '',
                'private_key' => '',
                'client_email' => '',
                'client_id' => '',
                'auth_uri' => '',
                'token_uri' => '',
                'auth_provider_x509_cert_url' => '',
                'client_x509_cert_url' => '',
            ],
        ];
    }

    /**
     * @return array
     */
    public function getDependencies(): array
    {
        return [
            'factories' => [
                Google_Client::class => ClientFactory::class,
                Google_Service_Drive::class => Service\Drive\DriveFactory::class,
                Google_Service_Sheets::class => Service\Sheets\SheetsFactory::class,

                Service\Drive\DriveMiddleware::class => Service\Drive\DriveMiddlewareFactory::class,
                Service\Sheets\SheetsMiddleware::class => Service\Sheets\SheetsMiddlewareFactory::class,
            ],
        ];
    }
}
